about summary refs log tree commit homepage
path: root/lib/PublicInbox/LeiOverview.pm
diff options
context:
space:
mode:
authorEric Wong <e@80x24.org>2021-02-07 08:51:53 +0000
committerEric Wong <e@80x24.org>2021-02-07 22:57:07 +0000
commit757652fd1ad6843c984610263a2a0b336c974111 (patch)
treed0a958b89fc49715c9e61c1e272227c6f31c7fab /lib/PublicInbox/LeiOverview.pm
parent2d610f0e645fd2b01bf9108b2d06022ab730815c (diff)
downloadpublic-inbox-757652fd1ad6843c984610263a2a0b336c974111.tar.gz
ipc: wq_do => wq_io_do
We will have a ->wq_do that doesn't pass FDs for I/O.
Diffstat (limited to 'lib/PublicInbox/LeiOverview.pm')
-rw-r--r--lib/PublicInbox/LeiOverview.pm4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/PublicInbox/LeiOverview.pm b/lib/PublicInbox/LeiOverview.pm
index 24e4c190..dcfb9cc7 100644
--- a/lib/PublicInbox/LeiOverview.pm
+++ b/lib/PublicInbox/LeiOverview.pm
@@ -23,7 +23,7 @@ my $JSONL = 'ldjson|ndjson|jsonl'; # 3 names for the same thing
 
 sub _iso8601 ($) { strftime('%Y-%m-%dT%H:%M:%SZ', gmtime($_[0])) }
 
# we open this in the parent process before ->wq_do handoff
 sub ovv_out_lk_init ($) {
         my ($self) = @_;
         my $tmp = File::Temp->new("lei-ovv.dst.$$.lock-XXXXXX",
@@ -205,7 +205,7 @@ sub ovv_each_smsg_cb { # runs in wq worker usually
                 sub {
                         my ($smsg, $mitem) = @_;
                         $smsg->{pct} = get_pct($mitem) if $mitem;
-                        $l2m->wq_do('write_mail', [], $git_dir, $smsg);
+                        $l2m->wq_io_do('write_mail', [], $git_dir, $smsg);
                 }
         } elsif ($self->{fmt} =~ /\A(concat)?json\z/ && $lei->{opt}->{pretty}) {
                 my $EOR = ($1//'') eq 'concat' ? "\n}" : "\n},";
@@ -23,7 +23,7 @@ my $JSONL = 'ldjson|ndjson|jsonl'; # 3 names for the same thing
 sub _iso8601 ($) { strftime('%Y-%m-%dT%H:%M:%SZ', gmtime($_[0])) }
 
-# we open this in the parent process before ->wq_do handoff
+# we open this in the parent process before ->wq_io_do handoff
 sub ovv_out_lk_init ($) {
         my ($self) = @_;